@@ -16,5 +16,14 @@
 
 """The Tornado web server and tools."""
 
-version = "2.0"
-version_info = (2, 0, 0)
+from __future__ import absolute_import, division, with_statement
+
+# version is a human-readable version number.
+
+# version_info is a four-tuple for programmatic comparison. The first
+# three numbers are the components of the version number.  The fourth
+# is zero for an official release, positive for a development branch,
+# or negative for a release candidate (after the base version number
+# has been incremented)
+version = "2.4.1"
+version_info = (2, 4, 1, 0)
